@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20231031';
+our $VERSION = '0.20231130';
 
-# Table last modified: 2023-10-31
+# Table last modified: 2023-11-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -108,9 +108,9 @@ our %ZIP_TABLE = (
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|1[0278]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[369]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|2[235]|0[1-8]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|1[0-246-9]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|1[0-246-9]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
@@ -488,7 +488,7 @@ our %ZIP_TABLE = (
     '516' => '(?:(?:8(?:5(?:20|77|3[03]|5[0-58]|8[018]|4[3-9]|6[67]|1[12568]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:29[2-68]|49[2-6]|192)|85(?:01|18|33)))',
-    '519' => '(?:(?:0(?:19[35-8]|59[2-5]|49[235]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
+    '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|1[0-356]|7[057]|5[058])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[01])1|0[23]92))',
     '522' => '(?:(?:8(?:5(?:11|0[135]|4[03]|3[39]|8[58]|2[023])|6(?:55|66))|029[27]))',
@@ -533,7 +533,7 @@ our %ZIP_TABLE = (
     '562' => '(?:8(?:5(?:11|22|43|55|8[0568]|0[58]|6[0278])|6(?:78|86)))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
     '564' => '(?:8(?:5(?:23|5[015]|0[13]|6[57]|1[15])|6(?:80|5[01])))',
-    '565' => '(?:85(?:11|40|65))',
+    '565' => '(?:85(?:11|40|85))',
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
     '567' => '(?:8(?:5(?:[34]0|57|1[015]|2[0135]|8[58]|6[57]|7[08]|0[1257])|6(?:51|80)))',
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
@@ -770,7 +770,7 @@ our %ZIP_TABLE = (
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|3[134679]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[2358]|49[2568]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
-    '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|4[0-35-8]|7[025-8]|5[0-79]|1[0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
+    '812' => '(?:(?:8(?:6(?:8[0134679]|[03][1-9]|4[0-35-8]|7[025-8]|5[0-79]|1[0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|77|1[39]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:65|77|0[135]|8[58]|1[0-2]|2[0245]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
